/*
 * Copyright (c) 2006-2007 Chris Smith, Shane Mc Cormack, Gregory Holmes
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package uk.org.ownage.dmdirc.commandparser.commands.query;

import uk.org.ownage.dmdirc.Query;
import uk.org.ownage.dmdirc.Config;
import uk.org.ownage.dmdirc.Server;
import uk.org.ownage.dmdirc.commandparser.QueryCommand;
import uk.org.ownage.dmdirc.commandparser.CommandWindow;

/**
 * Represents the /me command used in a query window, with no parameters.
 * Informs the user of the correct usage
 * @author chris
 */
public class QueryMeEmpty extends QueryCommand {
    
    /** Creates a new instance of QueryMeEmpty */
    public QueryMeEmpty() {
        description = "informs the user of the correct usage of the me command";
        arguments = "";
        polyadic = false;
        arity = 0;
        name = "me";
        show = false;
    }
    
    /**
     * Executes this command
     * @param origin The frame in which this command was issued
     * @param server The server object that this command is associated with
     * @param query The query object that this command is associated with
     * @param args The user supplied arguments
     */
    public void execute(CommandWindow origin, Server server, Query query, String... args) {
        origin.addLine("Usage: "+Config.getOption("general","commandchar")+"me <action>");
    }
    
}
